@@ -86,7 +86,7 @@ $tpl=new template("organizer", array(
     "ancLinks"      => $ancLinks,
     "selection"     => $selection,
     "coverphoto"    => $album->displayCoverPhoto(),
-    "description"   => $album->get("description"),
+    "description"   => $album->get("album_description"),
     "view"          => $_view,
     "view_name"     => "Album view",
     "view_hidden"   => null,
@@ -109,7 +109,7 @@ if ($user->canEditOrganizers()) {
 $tpl->addActionlinks($actionlinks);
 
 $sortorder = $album->get("sortorder");
-$sort = $sortorder ? $sortorder : "";
+$sort = $sortorder ? "&_order=" . $sortorder : "";
 
 $tpl->addBlock(new block("photoCount", array(
     "tpc"       => $album->getTotalPhotoCount(),
