@@ -27,7 +27,9 @@
  * @param string filename to load
  */
 function zophAutoload($file) {
-    if (is_readable(settings::$php_loc . "/" . $file)) {
+    if (is_readable("php/" . $file)) {
+        require_once $file;
+    } else if (is_readable(settings::$php_loc . "/" . $file)) {
         require_once $file;
     } else {
         return false;
