@@ -35,7 +35,7 @@ if ($user->prefs->get("show_breadcrumbs")) {
         $_action="";
     }
 
-    new breadcrumb($title, $_action);
+    breadcrumb::create($title, $_action);
 
     $_clear_crumbs = getvar("_clear_crumbs");
     $_crumb = getvar("_crumb");
