@@ -23,6 +23,7 @@
  */
 
 use conf\conf;
+use template\block;
 
 /**
  * Time class, extension of the standard PHP DateTime class
@@ -31,6 +32,11 @@ use conf\conf;
  * @package Zoph
  */
 class Time extends DateTime {
+
+    /** @var boolean is the date a fallback to the default (today)?
+                     if so, we don't want to display it in all cases... */
+    private $today = false;
+
     /**
      * Create Time object
      * @param string Date and time
@@ -38,6 +44,7 @@ class Time extends DateTime {
      * @return Time time object
      */
     public function __construct($datetime=null, $tz=null) {
+        $this->today=empty($datetime);
         try {
             if ($tz instanceof TimeZone && TimeZone::validate($tz->getName())) {
                 parent::__construct($datetime,$tz);
@@ -67,6 +74,22 @@ class Time extends DateTime {
         return $this->format(conf::get("date.format"));
     }
 
+   /**
+    * Get a link to the date
+    * @param string field to search for instead of the default 'date'
+    * @return template/block link
+    */
+    public function getLink($field = "date") {
+        if (!$this->today) {
+            return new block("link", array(
+                "link"  => $this->getFormatted(),
+                "href"  => "calendar.php?date=" . $this->getDate() .
+                           "&amp;search_field=" . $field,
+                "target" => ""
+            ));
+        }
+    }
+
 }
 
 
