@@ -132,7 +132,7 @@ class album extends zophTreeTable implements Organizer {
      */
     public function addPhoto(photo $photo) {
         $user=user::getCurrent();
-        if ($user->isAdmin() || $user->getAlbumPermissions($this)->get("writable")) {
+        if ($this->isWritableBy($user)) {
             $qry=new insert(array("photo_albums"));
             $qry->addParam(new param(":photo_id", (int) $photo->getId(), PDO::PARAM_INT));
             $qry->addParam(new param(":album_id", (int) $this->getId(), PDO::PARAM_INT));
@@ -146,7 +146,7 @@ class album extends zophTreeTable implements Organizer {
      */
     public function removePhoto(photo $photo) {
         $user=user::getCurrent();
-        if ($user->isAdmin() || $user->getAlbumPermissions($this)->get("writable")) {
+        if ($this->isWritableBy($user)) {
             $qry=new delete("photo_albums");
             $where=new clause("photo_id=:photo_id");
             $where->addAnd(new clause("album_id=:album_id"));
@@ -405,6 +405,15 @@ class album extends zophTreeTable implements Organizer {
         return $perms;
     }
 
+    /**
+     * Can the user write to this album?
+     * @param user user
+     * @return bool
+     */
+    public function isWritableBy(user $user) {
+        return $user->isAdmin() || $user->getAlbumPermissions($this)->get("writable");
+    }
+
     /**
      * Get a link to this album
      * @return string link to this album
