@@ -40,11 +40,25 @@ class update extends view {
      * Create the actionlinks for this page
      */
     protected function getActionlinks() {
-        return array(
-            translate("return")    => "albums.php?parent_album_id=" . $this->album->getId(),
-            translate("new")       => "album.php?_action=new&amp;parent_album_id=" . $this->album->getId(),
-            translate("delete")    => "album.php?_action=delete&amp;album_id=" . $this->album->getId()
-        );
+        if ($this->request["parent_album_id"] != 0) {
+            $returnURL = "albums.php?parent_album_id=" . $this->request["parent_album_id"];
+        } else if ($this->album->getId() != 0) {
+            $returnURL = "album.php?album_id=" . $this->album->getId();
+        } else {
+            $returnURL = "albums.php";
+        }
+
+        if ($this->request["_action"] == "new") {
+            return array(
+                translate("return")    => $returnURL
+            );
+        } else {
+            return array(
+                translate("return")    => $returnURL,
+                translate("new")       => "album.php?_action=new&amp;parent_album_id=" . $this->album->getId(),
+                translate("delete")    => "album.php?_action=delete&amp;album_id=" . $this->album->getId()
+            );
+        }
     }
 
     /**
@@ -58,13 +72,10 @@ class update extends view {
         if ($this->request["_action"] == "new") {
             $action = "insert";
 
-            // no point in including a 'new' link on the 'new' page:
-            unset($actionlinks["new"]);
-
             $permissions=new block("message", array(
-                        "class" => "info",
-                        "text" => translate("After this album has been created, groups can be given access to it."
-                    )));
+                "class" => "info",
+                "text" => translate("After this album has been created, groups can be given access to it.")
+            ));
         } else if ($this->request["_action"] == "edit") {
             $action = "update";
             $editPermissions=new editPermissions($this->album);
