@@ -40,11 +40,25 @@ class update extends view {
      * Create the actionlinks for this page
      */
     protected function getActionlinks() {
-        return array(
-            translate("return")    => "categories.php?parent_category_id=" . $this->category->getId(),
-            translate("new")       => "category.php?_action=new&amp;parent_category_id=" . $this->category->getId(),
-            translate("delete")    => "category.php?_action=delete&amp;category_id=" . $this->category->getId()
-        );
+        if ($this->request["parent_category_id"] != 0) {
+            $returnURL = "categories.php?parent_category_id=" . $this->request["parent_category_id"];
+        } else if ($this->category->getId() != 0) {
+            $returnURL = "category.php?category_id=" . $this->category->getId();
+        } else {
+            $returnURL = "categories.php";
+        }
+
+        if ($this->request["_action"] == "new") {
+            return array(
+                translate("return")    => $returnURL
+            );
+        } else {
+            return array(
+                translate("return")    => $returnURL,
+                translate("new")       => "category.php?_action=new&amp;parent_category_id=" . $this->category->getId(),
+                translate("delete")    => "category.php?_action=delete&amp;category_id=" . $this->category->getId()
+            );
+        }
     }
 
     /**
@@ -57,10 +71,6 @@ class update extends view {
 
         if ($this->request["_action"] == "new") {
             $action = "insert";
-
-            // no point in including a 'new' link on the 'new' page:
-            unset($actionlinks[translate("new")]);
-
         } else if ($this->request["_action"] == "edit") {
             $action = "update";
         } else {
