@@ -105,16 +105,10 @@ class arguments {
 
 
             case "--access":
-                $access=explode(",",$argv[++$i]);
-                foreach ($access as $acc) {
-                    $args["_add_access"][]=trim($acc);
-                }
+                $this->argsAddAccess(explode(",",$argv[++$i]));
                 break;
             case "--no-access":
-                $access=explode(",",$argv[++$i]);
-                foreach ($access as $acc) {
-                    $args["_remove_access"][]=trim($acc);
-                }
+                $this->argsRemoveAccess(explode(",",$argv[++$i]));
                 break;
             case "--admin":
                 $args["_admin"]=true;
@@ -126,26 +120,14 @@ class arguments {
             case "--albums":
             case "--album":
             case "-a":
-                $albums=explode(",",$argv[++$i]);
-                foreach ($albums as $album) {
-                    $args["albums"][]=trim($album);
-                    if (isset($parent)) {
-                        $args["palbum"][]=trim($parent);
-                    }
-                }
+                $this->argsAlbums(explode(",",$argv[++$i]), $parent);
                 $parent=0;
                 break;
 
             case "--category":
             case "--categories":
             case "-c":
-                $cats=explode(",",$argv[++$i]);
-                foreach ($cats as $cat) {
-                    $args["categories"][]=trim($cat);
-                    if (isset($parent)) {
-                        $args["pcat"][]=trim($parent);
-                    }
-                }
+                $this->argsCategories(explode(",",$argv[++$i]), $parent);
                 $parent=0;
                 break;
 
@@ -181,10 +163,6 @@ class arguments {
                     $args["_groups"][]=trim($group);
                 }
                 break;
-
-            case "--import":
-                static::$command="import";
-                break;
             case "--place":
             case "--location":
             case "-l":
@@ -407,6 +385,37 @@ class arguments {
             static::$command="update";
         }
     }
+
+    private function argsAddAccess(array $access) {
+        foreach ($access as $acc) {
+            $this->processed["_add_access"][]=trim($acc);
+        }
+    }
+
+    private function argsRemoveAccess(array $access) {
+        foreach ($access as $acc) {
+            $this->processed["_remove_access"][]=trim($acc);
+        }
+    }
+
+    private function argsAlbums(array $albums, $parent=null) {
+        foreach ($albums as $album) {
+            $this->processed["albums"][]=trim($album);
+            if (isset($parent)) {
+                $this->processed["palbum"][]=trim($parent);
+            }
+        }
+    }
+
+    private function argsCategories(array $categories, $parent=null) {
+        foreach ($categories as $cat) {
+            $this->processed["categories"][]=trim($cat);
+            if (isset($parent)) {
+                $this->processed["pcat"][]=trim($parent);
+            }
+        }
+    }
+
     /**
      * Looks up the given parameters in the database and gives back ids
      */
@@ -421,135 +430,19 @@ class arguments {
             log::msg($type . "\t->\t" . implode(",", (array) $arg), log::DEBUG, log::IMPORT);
             switch($type) {
             case "albums":
-                foreach ($arg as $name) {
-                    if (static::$command=="new" ||
-                      (conf::get("import.cli.add.auto") && !album::getByName($name))) {
-                        $parent=array_shift($args["palbum"]);
-                        // this is a string comparison because the trim() in process() changes
-                        // everything into a string...
-                        if ($parent==="0") {
-                            if (conf::get("import.cli.add.always")) {
-                                $parent_id=album::getRoot()->getId();
-                            } else {
-                                throw new \cliNoParentException("No parent for album " . $name);
-                            }
-                        } else {
-                            $palbum=album::getByName($parent);
-                            if ($palbum) {
-                                $parent_id=$palbum[0]->getId();
-                            } else {
-                                throw new \albumNotFoundException("Album not found: $parent");
-                            }
-                        }
-                        $vars["_new_album"][]=array("parent" => $parent_id, "name" => $name);
-                    } else {
-                        $album=album::getByName($name);
-                        if ($album) {
-                            $album_id=$album[0]->getId();
-                            $vars["_album_id"][]=$album_id;
-                        } else {
-                            throw new \albumNotFoundException("Album not found: $name");
-                        }
-                    }
-                }
+                $this->lookupAlbums($arg, $args["palbum"]);
                 break;
             case "categories":
-                foreach ($arg as $name) {
-                    if (static::$command=="new" ||
-                      (conf::get("import.cli.add.auto") && !category::getByName($name))) {
-                        $parent=array_shift($args["pcat"]);
-                        // this is a string comparison because the trim() in process() changes
-                        // everything into a string...
-                        if ($parent==="0") {
-                            if (conf::get("import.cli.add.always")) {
-                                $parent_id=category::getRoot()->getId();
-                            } else {
-                                throw new \cliNoParentException("No parent for category " . $name);
-                            }
-                        } else {
-                            $pcat=category::getByName($parent);
-                            if ($pcat) {
-                                $parent_id=$pcat[0]->getId();
-                            } else {
-                                throw new \categoryNotFoundException("Category not found: $parent");
-                            }
-                        }
-                        $vars["_new_cat"][]=array("parent" => $parent_id, "name" => $name);
-                    } else {
-                        $cat=category::getByName($name);
-                        if ($cat) {
-                            $cat_id=$cat[0]->getId();
-                            $vars["_category_id"][]=$cat_id;
-                        } else {
-                            throw new \categoryNotFoundException("Category not found: $name");
-                        }
-                    }
-                }
+                $this->lookupCategories($arg, $args["pcat"]);
                 break;
             case "people":
-                foreach ($arg as $name) {
-                    if (static::$command=="new" || (conf::get("import.cli.add.auto") &&
-                      !person::getByName($name))) {
-                        $vars["_new_person"][]=$name;
-                    } else {
-                        $person=person::getByName($name);
-                        if ($person) {
-                            $person_id=$person[0]->getId();
-                            $vars["_person_id"][]=$person_id;
-                        } else {
-                            throw new \personNotFoundException("Person not found: $name");
-                        }
-                    }
-                }
+                $this->lookupPeople($arg);
                 break;
             case "photographer":
-                $name=$arg;
-                if (static::$command=="new" ||
-                  (conf::get("import.cli.add.auto") && !person::getByName($name))) {
-                    $vars["_new_photographer"][]=$name;
-                } else {
-                    $person=person::getByName($name);
-                    if ($person) {
-                        $person_id=$person[0]->getId();
-                        $vars["photographer_id"]=$person_id;
-                    } else {
-                        throw new \personNotFoundException("Person not found: $name");
-                    }
-                }
+                $this->lookupPhotographer($arg);
                 break;
             case "location":
-                foreach ($arg as $name) {
-                    if (static::$command=="new" || (conf::get("import.cli.add.auto") &&
-                      !place::getByName($name))) {
-                        $parent=array_shift($args["pplace"]);
-                        // this is a string comparison because the trim() in process() changes
-                        // everything into a string...
-                        if ($parent==="0") {
-                            if (conf::get("import.cli.add.always")) {
-                                $parent_id=place::getRoot()->getId();
-                            } else {
-                                throw new \cliNoParentException("No parent for location " . $name);
-                            }
-                        } else {
-                            $pplace=place::getByName($parent);
-                            if ($pplace) {
-                                $parent_id=$pplace[0]->getId();
-                            } else {
-                                throw new \placeNotFoundException("Location not found: $parent");
-                            }
-                        }
-                        $vars["_new_place"][]=array("parent" => $parent_id, "name" => $name);
-                    } else {
-                        $name=$arg[0];
-                        $place=place::getByName($name);
-                        if ($place) {
-                            $place_id=$place[0]->getId();
-                            $vars["location_id"]=$place_id;
-                        } else {
-                            throw new \placeNotFoundException("Location not found: $name");
-                        }
-                    }
-                }
+                $this->lookupLocations($arg, $args["pplace"]);
                 break;
             case "path":
                 $vars["_path"]=$arg;
@@ -603,6 +496,8 @@ class arguments {
             case "_getconfigitem":
                 $vars[$type]=$arg;
                 break;
+            default:
+                log::msg($type . "\t->\t" . implode(",", (array) $arg), log::ERROR, log::IMPORT);
             }
         }
     }
@@ -620,5 +515,136 @@ class arguments {
         return $this->vars;
     }
 
+    private function lookupAlbums(array $albums, $parents) {
+        foreach ($albums as $name) {
+            if (static::$command=="new" ||
+              (conf::get("import.cli.add.auto") && !album::getByName($name))) {
+                $parent=array_shift($parents);
+                // this is a string comparison because the trim() in process() changes
+                // everything into a string...
+                if ($parent==="0") {
+                    if (conf::get("import.cli.add.always")) {
+                        $parent_id=album::getRoot()->getId();
+                    } else {
+                        throw new \cliNoParentException("No parent for album " . $name);
+                    }
+                } else {
+                    $palbum=album::getByName($parent);
+                    if ($palbum) {
+                        $parent_id=$palbum[0]->getId();
+                    } else {
+                        throw new \albumNotFoundException("Album not found: $parent");
+                    }
+                }
+                $this->vars["_new_album"][]=array("parent" => $parent_id, "name" => $name);
+            } else {
+                $album=album::getByName($name);
+                if ($album) {
+                    $this->vars["_album_id"][]=$album[0]->getId();
+                } else {
+                    throw new \albumNotFoundException("Album not found: $name");
+                }
+            }
+        }
+    }
+
+    private function lookupCategories(array $categories, $parents) {
+        foreach ($categories as $name) {
+            if (static::$command=="new" ||
+              (conf::get("import.cli.add.auto") && !category::getByName($name))) {
+                $parent=array_shift($parents);
+                // this is a string comparison because the trim() in process() changes
+                // everything into a string...
+                if ($parent==="0") {
+                    if (conf::get("import.cli.add.always")) {
+                        $parent_id=category::getRoot()->getId();
+                    } else {
+                        throw new \cliNoParentException("No parent for category " . $name);
+                    }
+                } else {
+                    $pcat=category::getByName($parent);
+                    if ($pcat) {
+                        $parent_id=$pcat[0]->getId();
+                    } else {
+                        throw new \categoryNotFoundException("Category not found: $parent");
+                    }
+                }
+                $this->vars["_new_cat"][]=array("parent" => $parent_id, "name" => $name);
+            } else {
+                $cat=category::getByName($name);
+                if ($cat) {
+                    $this->vars["_category_id"][]=$cat[0]->getId();
+                } else {
+                    throw new \categoryNotFoundException("Category not found: $name");
+                }
+            }
+        }
+    }
+
+    private function lookupPeople(array $people) {
+        foreach ($people as $name) {
+            if (static::$command=="new" || (conf::get("import.cli.add.auto") &&
+              !person::getByName($name))) {
+                $this->vars["_new_person"][]=$name;
+            } else {
+                $person=person::getByName($name);
+                if ($person) {
+                    $person_id=$person[0]->getId();
+                    $this->vars["_person_id"][]=$person_id;
+                } else {
+                    throw new \personNotFoundException("Person not found: $name");
+                }
+            }
+        }
+    }
+    private function lookupPhotographer(string $name) {
+        if (static::$command=="new" ||
+          (conf::get("import.cli.add.auto") && !person::getByName($name))) {
+            $this->vars["_new_photographer"][]=$name;
+        } else {
+            $person=person::getByName($name);
+            if ($person) {
+                $person_id=$person[0]->getId();
+                $this->vars["photographer_id"]=$person_id;
+            } else {
+                throw new \personNotFoundException("Person not found: $name");
+            }
+        }
+    }
+
+    private function lookupLocations(array $locations, $parents) {
+        foreach ($locations as $name) {
+            if (static::$command=="new" || (conf::get("import.cli.add.auto") &&
+              !place::getByName($name))) {
+                $parent=array_shift($parents);
+                // this is a string comparison because the trim() in process() changes
+                // everything into a string...
+                if ($parent==="0") {
+                    if (conf::get("import.cli.add.always")) {
+                        $parent_id=place::getRoot()->getId();
+                    } else {
+                        throw new \cliNoParentException("No parent for location " . $name);
+                    }
+                } else {
+                    $pplace=place::getByName($parent);
+                    if ($pplace) {
+                        $parent_id=$pplace[0]->getId();
+                    } else {
+                        throw new \placeNotFoundException("Location not found: $parent");
+                    }
+                }
+                $this->vars["_new_place"][]=array("parent" => $parent_id, "name" => $name);
+            } else {
+                $name=$locations[0];
+                $place=place::getByName($name);
+                if ($place) {
+                    $place_id=$place[0]->getId();
+                    $this->vars["location_id"]=$place_id;
+                } else {
+                    throw new \placeNotFoundException("Location not found: $name");
+                }
+            }
+        }
+    }
 }
 ?>
