@@ -79,6 +79,7 @@ class cli {
         if (!$user->isAdmin()) {
             throw new \cliUserNotAdminException("CLI_USER must be an admin user");
         }
+        user::setCurrent($user);
         $user->prefs->load();
         $user->loadLanguage();
         $this->args=new arguments($args);
@@ -220,7 +221,7 @@ class cli {
 
             // check if path is in conf::get("path.images")
             if (substr($path, 0, strlen(conf::get("path.images")))!=conf::get("path.images")) {
-                throw new \importFileNotInPathException($file ." is not in the images path (" .
+                throw new \importFileNotInPathException($path . "/" . $file ." is not in the images path (" .
                     conf::get("path.images") . "), skipping.\n");
             } else {
                 $path=substr($path, strlen(conf::get("path.images")));
@@ -233,7 +234,12 @@ class cli {
             $path=file::cleanupPath($path);
         }
         $photos=photo::getByName($filename, $path);
-        if (sizeof($photos)==0) {
+
+        if (empty($photos)) {
+            $photos=photo::getByName($filename);
+        }
+
+        if (empty($photos)) {
             throw new \importFileNotFoundException($file ." not found.\n");
         } else if (sizeof($photos)==1) {
             return $photos[0];
@@ -250,7 +256,7 @@ class cli {
         if (conf::get("import.cli.add.auto")) {
             $vars=$this->addNew();
         }
-        if (is_array($this->files) && sizeof($this->files)>0) {
+        if (is_array($this->files) && !empty($this->files)) {
             if (!isset($vars["_dirpattern"])) {
                 $photos=array();
                 foreach (array_unique($this->files) as $file) {
@@ -260,7 +266,7 @@ class cli {
                     if (isset($vars["_xmp"])) {
                         $xmp = new xmpReader($file);
                         $data=new xmpdecoder($xmp->getXMP());
-                        foreach($data->getSubjects() as $subject) {
+                        foreach ($data->getSubjects() as $subject) {
                             $categories = category::getByName($subject);
                             $category = array_pop($categories);
                             if ($category instanceof category) {
@@ -291,7 +297,7 @@ class cli {
      * Process --update
      */
     private function doUpdate() {
-        if (is_array($this->photos) && sizeof($this->photos)>0) {
+        if (is_array($this->photos) && !empty($this->photos)) {
             $total=sizeof($this->photos);
             $cur=0;
             foreach ($this->photos as $photo) {
@@ -491,7 +497,7 @@ class cli {
         $groups = array_map(
             function($g) {
                 $g->lookup();
-                return $g->getName(); 
+                return $g->getName();
             }, $u->getGroups()
         );
 
