@@ -90,16 +90,21 @@ class variable {
         if (is_array($var)) {
             $return=array();
             foreach ($var as $key => $arrayValue) {
-                $return[static::escape($key)]=static::escape($arrayValue);
+                $return[static::htmlEscape($key)]=static::htmlEscape($arrayValue);
             }
         } else {
-            $return=htmlspecialchars($var);
-            /* Extra escape for a few chars that may cause troubles but are
-               not escaped by htmlspecialchars. */
-            $return=str_replace(array("<", ">", "\"", "(", ")", "'", "[",  "]", "{", "}", "~", "`"),
-                array("&lt;", "&gt;", "&quot;", "&#40;", "&#41;", "&#39;","&#91;", "&#93;", "&#123;",
-                  "&#125;", "&#126;", "&#96;"), $return);
+            $return=static::htmlEscape($var);
         }
         return $return;
     }
+
+    public static function htmlEscape($var) {
+        $return=htmlspecialchars($var);
+        /* Extra escape for a few chars that may cause troubles but are
+           not escaped by htmlspecialchars. */
+        $return=str_replace(array("<", ">", "\"", "(", ")", "'", "[",  "]", "{", "}", "~", "`"),
+            array("&lt;", "&gt;", "&quot;", "&#40;", "&#41;", "&#39;","&#91;", "&#93;", "&#123;",
+              "&#125;", "&#126;", "&#96;"), $return);
+        return $return;
+    }
 }
