@@ -48,6 +48,28 @@ class controller extends genericController {
         $this->doAction();
     }
 
+    protected function actionDisplay() {
+        $this->view = new view\display($this->request, $this->object);
+    }
+
+    protected function actionDelete() {
+        $this->view = new view\confirm($this->request, $this->object);
+    }
+
+    protected function actionEdit() {
+        $this->view = new view\update($this->request, $this->object);
+    }
+
+    protected function actionNew() {
+        $this->view = new view\update($this->request, $this->object);
+    }
+
+    protected function actionConfirm() {
+        parent::actionConfirm();
+        $this->view = new view\redirect($this->request, $this->object);
+        $this->view->setRedirect("groups.php");
+    }
+
     /**
      * Action: update
      * The update action processes a form as generated after the "edit" action.
@@ -66,7 +88,7 @@ class controller extends genericController {
             }
         }
         $this->object->update();
-        $this->view = "update";
+        $this->view = new view\update($this->request, $this->object);
     }
 
     /**
@@ -78,6 +100,6 @@ class controller extends genericController {
      */
     protected function actionInsert() {
         parent::actionInsert();
-        $this->view="update";
+        $this->view = new view\update($this->request, $this->object);
     }
 }
