@@ -207,7 +207,8 @@ class web extends base {
             $return=static::unpackArchive($file);
             break;
         case "gpx":
-            $return=static::XMLimport($file);
+            static::XMLimport($file);
+            $return=null;
             break;
         default:
             log::msg("Unknown filetype " . $type .
@@ -251,6 +252,7 @@ class web extends base {
             $extr = conf::get("path.untar");
             $msg = "Untar command";
             break;
+        case "application/gzip":
         case "application/x-gzip":
             $extr = conf::get("path.ungz");
             $msg = "Ungzip command";
@@ -352,59 +354,13 @@ class web extends base {
 
     /**
      * Get XML for Import
-     * @todo This is a temporary function to distinguish between the two XML responses
-     *       this class can give. Eventually, both functions should be called directly
      */
     public static function getXML($search) {
         if ($search=="thumbs") {
             return static::getThumbsXML();
-        } else {
-            return static::getProgressXML($search);
         }
     }
 
-    /**
-     * Get XML indicating progress of a certain upload
-     */
-    public static function getProgressXML($uploadId) {
-        $xml = new \DOMDocument('1.0','UTF-8');
-        $rootnode=$xml->createElement(static::XMLROOT);
-        $node=$xml->createElement(static::XMLNODE);
-
-        if (ini_get("session.upload_progress.enabled")==true) {
-            $upl_prog=$_SESSION[ini_get("session.upload_progress.prefix") . $uploadId];
-            $progress['current']=$upl_prog["bytes_processed"];
-            $progress['total']=$upl_prog["content_length"];
-            // for now we take the first file as multiple uploads
-            // are not yet supported
-            $progress['filename']=$upl_prog["files"][0]["name"];
-        } else {
-            // session.upload_progress not enables extension not available
-            $progress['current']=0;
-            $progress['total']=0;
-            $progress['filename']="Enable session.upload_progress.enabled in php.ini";
-        }
-
-        $id=$xml->createElement("id");
-        $current=$xml->createElement("current");
-        $total=$xml->createElement("total");
-        $filename=$xml->createElement("filename");
-
-        $id->appendChild($xml->createTextNode($uploadId));
-        $current->appendChild($xml->createTextNode($progress['current']));
-        $total->appendChild($xml->createTextNode($progress['total']));
-        $filename->appendChild($xml->createTextNode($progress['filename']));
-
-        $node->appendChild($id);
-        $node->appendChild($current);
-        $node->appendChild($total);
-        $node->appendChild($filename);
-
-        $rootnode->appendChild($node);
-        $xml->appendChild($rootnode);
-        return $xml;
-    }
-
     /**
      * Generate an XML file with thumbs in the import dir
      */
