@@ -298,6 +298,10 @@ class photo extends zophTable {
         foreach ($people as $person) {
             $this->addTo(new person($person));
         }
+
+        if (isset($this->_rate)) {
+            $this->rate($this->_rate);
+        }
     }
 
     /**
@@ -869,7 +873,7 @@ class photo extends zophTable {
      * @return array photo properties
      */
     public function getDisplayArray() {
-        $date=$this->getReverseDate();
+        $date=new Time($this->getReverseDate());
 
         $loclink="";
         if ($this->location instanceof place) {
@@ -893,7 +897,7 @@ class photo extends zophTable {
             translate("title") => $this->get("title"),
             translate("location") => $loclink,
             translate("view") => $this->get("view"),
-            translate("date") => create_date_link($date),
+            translate("date") => $date->getLink(),
             translate("time") => $this->getTimeDetails(),
             translate("photographer") => $pglink
         );
