@@ -56,9 +56,9 @@ class confirm {
      */
     public function view() {
         $actionlinks=array(
-            "confirm"   =>  "photo.php?_action=confirm&amp;photo_id=" . $this->photo->getId() .
+            translate("confirm")   =>  "photo.php?_action=confirm&amp;photo_id=" . $this->photo->getId() .
                             "&amp;_qs=" . $this->request->getPassedQueryString()->encode(),
-            "cancel"    =>  "photo.php?" . $this->request->getPassedQueryString()
+            translate("cancel")    =>  "photo.php?" . $this->request->getPassedQueryString()
         );
         return new template("confirm", array(
             "title"     =>  translate("delete photo"),
