@@ -48,11 +48,11 @@ class update extends common {
     protected function getActionlinks() {
         $actionlinks=parent::getActionLinks();
         $user=user::getCurrent();
-        unset($actionlinks["edit"]);
+        unset($actionlinks[translate("edit")]);
         if (!$user->prefs->get("auto_edit")) {
-            $actionlinks["return"]="photo.php?" .  $this->request->getReturnQueryString();
+            $actionlinks[translate("return")]="photo.php?" .  $this->request->getReturnQueryString();
         } else {
-            $actionlinks["display"]="photo.php?_action=display&amp;" .  $this->request->getReturnQueryString();
+            $actionlinks[translate("display")]="photo.php?_action=display&amp;" .  $this->request->getReturnQueryString();
         }
         return $actionlinks;
     }
@@ -66,7 +66,7 @@ class update extends common {
         $warning = "";
         $autocomppeople = "true";
 
-        if(!person::getAutocompPref()) {
+        if (!person::getAutocompPref()) {
             $warning = new block("message", array(
                 "class" => "warning",
                 "text" => translate("Autocomplete for people is needed to add people to a photo")
@@ -88,7 +88,7 @@ class update extends common {
             "up"                => $this->upURL,
             "next"              => $this->nextURL,
             "full"              => $photo->getFullsizeLink($photo->get("name")),
-            "size"              => template::getHumanReadableBytes($photo->get("size")),
+            "size"              => template::getHumanReadableBytes((int) $photo->get("size")),
             "share"             => $this->getShare(),
             "image"             => $photo->getFullsizeLink($photo->getImageTag(MID_PREFIX)),
             "albums"            => $photo->getAlbums($user),
