@@ -29,6 +29,14 @@ use db\db;
 use db\clause;
 use db\selectHelper;
 
+use conf\conf;
+
+use geo\map;
+use geo\marker;
+
+use template\block;
+use template\template;
+
 /**
  * A class corresponding to the places table.
  *
@@ -52,6 +60,12 @@ class place extends zophTreeTable implements Organizer {
     protected static $primaryKeys=array("place_id");
     /** @var array Fields that may not be empty */
     protected static $notNull=array("title");
+    /** @var array Fields that are integers */
+    protected static $isInteger=array(
+        "place_id", "parent_place_id", "contact_type", "coverphoto", "pageset", "mapzoom", "createdby"
+    );
+    /** @var array Fields that are floats */
+    protected static $isFloat=array("lat", "lon");
     /** @var bool keep keys with insert. In most cases the keys are set
                   by the db with auto_increment */
     protected static $keepKeys = false;
@@ -402,7 +416,7 @@ class place extends zophTreeTable implements Organizer {
      * @return marker instance of marker class
      */
     public function getMarker($icon="geo-place") {
-        return map::getMarkerFromObj($this, $icon);
+        return marker::getFromObj($this, $icon);
     }
 
     /**
