@@ -44,27 +44,14 @@ class controller extends genericController {
      * @param request request
      */
     public function __construct(request $request) {
+        $_action = $request["_action"];
         parent::__construct($request);
         if (isset($this->request["search_id"])) {
             $search = new search($this->request["search_id"]);
             $search->lookup();
-        } else if ($this->request["_action"]=="new") {
-            $vars=$request->getRequestVarsClean();
-            unset($vars["_action"]);
-            unset($vars["_crumb"]);
-            $urlVars=array();
-
-            foreach ($vars as $key => $val) {
-                // Change key#0 into key[0]:
-                $key=preg_replace("/\#([0-9]+)/", "[$1]", $key);
-                // Change key[0]-children into key_children[0] because everything
-                // after ] in a variable name is lost fix for bug#2890387
-                $key=preg_replace("/\[(.+)\]-([a-z]+)/", "_$2[$1]", $key);
-                $urlVars[]=e($key) . "=" . e($val);
-            }
-            $url = implode("&amp;", $urlVars);
+        } else if ($_action=="new") {
             $search=new search();
-            $search->set("search", $url);
+            $search->setSearchURL($this->request);
             $search->set("owner", user::getCurrent()->getId());
         } else {
             $search=new search();
