@@ -123,7 +123,7 @@ class display {
                 "op"    => array("template\\template", "createBinaryOperatorPulldown"),
                 "value" => array("place", "createPullDown"),
                 "child" => "location_id_children",
-                "child_label"   => translate("include sub-locations")
+                "child_label"   => translate("include sub-places")
             ),
             "rating"     => array(
                 "label" => translate("rating"),
