@@ -84,7 +84,7 @@ class template {
             }
             $this->template=$file;
 
-            $this->css[]="css.php";
+            $this->vars["css"][]="css.php";
         } else {
             log::msg("Illegal characters in template", log::FATAL, log::GENERAL);
         }
@@ -132,42 +132,6 @@ class template {
         }
     }
 
-    /**
-     * Return the header section of the page
-     *
-     * @return string
-     * @access private
-     * @todo This should be in a template, cannot be done at the moment because
-     *       there are so many pages not moved to the templating system.
-     */
-    private function getHead() {
-        $html="";
-        foreach ($this->js as $js_src) {
-            $html.="    <script type='text/javascript' src='" . $js_src . "'>" .
-                "</script>\n";
-        }
-
-        if (!empty($this->script)) {
-            $html.="    <script type='text/javascript'>";
-            $html.="        " . $this->script;
-            $html.="    </script>";
-        }
-
-        foreach ($this->css as $css_href) {
-            $html.="    <link type='text/css' rel='stylesheet' href='" .
-                $css_href . "'>\n";
-        }
-        if (!empty($this->style)) {
-            $html.="    <style>" . $this->style . "</style>\n";
-        }
-        if (!empty($title)) {
-            $html.="    <title>" . $title . "</title>\n";
-        }
-
-        return $html;
-    }
-
-
     /**
      * Add a block
      * @param block Block to be added
