@@ -247,6 +247,30 @@ class request implements ArrayAccess {
         }
     }
 
+   /**
+    * Update requestvars
+    * Update a variable to a new value, remove ignored keys
+    * always removes PHPSESSID and _crumb variables
+    * @param string variable (key) to add / update
+    * @param mixed value of the new /updated variable
+    * @param array list of key names to remove
+    * @return array updated variables
+    */
+    public function getUpdatedVars($new, $val, $ignore = array()) {
+        $ignore[] = "PHPSESSID";
+        $ignore[] = "_crumb";
+
+        $vars = $this->getRequestVars();
+
+        foreach ($ignore as $key) {
+            unset($vars[$key]);
+        }
+
+        $vars[$new] = $val;
+
+        return $vars;
+    }
+
     /**
      * Remove any params without values and operator params without corresponding
      * fields (e.g. _album_id-op when there is no _album_id).  This can be called
@@ -356,4 +380,5 @@ class request implements ArrayAccess {
 
         return $cleanVars;
     }
+
 }
