@@ -27,23 +27,26 @@ use conf\conf;
 use web\request;
 use geo\locationLookup;
 use photo\data as photoData;
+use photo\people as photoPeople;
 use photo\collection;
 use photo;
+use person;
 use user;
 /**
  * Controller for web services
  */
 class controller {
     /** @var request holds request */
-    private   $request;
+    private $request;
 
     /** @var array holds data */
-    private   $data;
+    private $data;
 
     /** @var array Actions that can be used in this controller */
-    private   $actions    = array(
+    private $actions = array(
         "locationLookup",
         "photoData",
+        "photoPeople",
         "search"
     );
 
@@ -100,13 +103,64 @@ class controller {
         $this->view = "json";
         $photoId = $this->request["photoId"];
         $photo = new photo($photoId);
-        $user=user::getCurrent();
         if ($photo->lookup()) {
             $data = new photoData($photo);
             $this->data = $data->getData();
         }
     }
 
+    /**
+     * Do action 'photoPeople'
+     */
+    public function actionPhotoPeople() {
+        $this->view = "json";
+        $photoId = (int) $this->request["photoId"];
+        $personId = (int) $this->request["personId"];
+        $photo = new photo($photoId);
+        $person = new person($personId);
+        $photoPeople = new photoPeople($photo);
+        $user=user::getCurrent();
+
+        if (!$photo->isWritableBy($user)) {
+            return;
+        }
+
+        $action = $this->request["action"];
+        switch($action) {
+            case "left":
+                list($row, $pos) = $photoPeople->getPosition($person);
+                $photoPeople->setPosition($person, $pos - 1);
+                break;
+            case "right":
+                list($row, $pos) = $photoPeople->getPosition($person);
+                $photoPeople->setPosition($person, $pos + 1);
+                break;
+            case "up":
+                list($row, $pos) = $photoPeople->getPosition($person);
+                $photoPeople->setRow($person, $row - 1);
+                break;
+            case "down":
+                list($row, $pos) = $photoPeople->getPosition($person);
+                $photoPeople->setRow($person, $row + 1);
+                break;
+            case "add":
+                $row = (int) $this->request["row"];
+                $person->addPhoto($photo);
+                $photoPeople->setRow($person, $row);
+                break;
+            case "remove":
+                $person->removePhoto($photo);
+                break;
+            default:
+                // Not making any changes, just outputting status quo
+                break;
+        }
+        if ($photo->lookup()) {
+            $data = new photoPeople($photo);
+            $this->data = $data->getData();
+        }
+    }
+
     public function actionSearch() {
         $this->view = "json";
         $photoCollection = collection::createFromRequest($this->request);
@@ -117,6 +171,6 @@ class controller {
 
     private static function getId(photo $photo) {
         return $photo->getId();
-    }    
-        
+    }
+
 }
