@@ -36,13 +36,13 @@ class decoder implements \Countable {
     }
 
     public function getSubjects() {
-        if ($this->xmpdata and sizeof($this->xmpdata) > 0) {
-            return (array) $this->xmpdata[0]->getRDFDescription("dc:subject");
+        if ($this->xmpdata and !empty($this->xmpdata)) {
+            return $this->xmpdata[0]->getRDFDescription("dc:subject");
         }
     }
-    
+
     public function getRating() {
-        if ($this->xmpdata and sizeof($this->xmpdata) > 0) {
+        if ($this->xmpdata && !empty($this->xmpdata)) {
             $rating = (int) $this->xmpdata[0]->getRDFDescription("xmp:Rating");
             if ($rating != 0) {
                 return $rating;
