@@ -386,7 +386,10 @@ abstract class zophTable {
         reset($keys);
         $da=array();
         foreach ($keys as $k) {
-            if ($this->isKey($k)) { continue; }
+            if ($this->isKey($k)) {
+                continue;
+            }
+
             $title = ucfirst(str_replace("_", " ", $k));
             $da[$title] = $this->fields[$k];
         }
