@@ -23,6 +23,7 @@
 
 use conf\conf;
 use comment\controller;
+use template\template;
 use web\request;
 
 require_once "include.inc.php";
@@ -35,7 +36,8 @@ $request = request::create();
 try {
     $controller = new controller($request);
 } catch (securityException $e) {
-    $tpl=new template\template("error", array(
+    $tpl=new template("error", array(
+        "lang"          => language::getCurrentISO(),
         "title"         => "Security Error",
         "message"       => $e->getMessage(),
     ));
