@@ -21,6 +21,7 @@
  * @author Jeroen Roos
  */
 use conf\conf;
+use template\template;
 
 require_once "include.inc.php";
 
@@ -28,20 +29,17 @@ if (!conf::get("feature.comments")) {
     redirect("zoph.php");
 }
 
-require_once "header.inc.php";
-?>
-<h1>
-  <?php echo translate("Comments") ?>
-</h1>
-<div class="main">
-  <br>
-<?php
+$tpl = new template("main", array(
+    "title"     => translate("Comments")
+));
+
 $comments=comment::getRecords();
 foreach ($comments as $comment) {
     $photo=$comment->getPhoto();
     if ($user->getPhotoPermissions($photo) || $user->canSeeAllPhotos()) {
-        echo $comment->toHTML(true);
+        $tpl->addBlock($comment->toHTML(true));
     }
 }
-require_once "footer.inc.php";
+
+echo $tpl;
 ?>
