@@ -21,6 +21,9 @@
  * @author Jeroen Roos
  */
 
+use conf\conf;
+use template\template;
+
 require_once "include.inc.php";
 $title=translate("Configuration");
 
@@ -37,7 +40,6 @@ $_action=getvar("_action");
 if ($_action == "setconfig") {
     conf::loadFromRequestVars($request_vars);
 }
-conf::loadFromDB();
 
 $tpl=new template("config", array(
     "title" => $title,
