@@ -22,7 +22,7 @@ header("Content-Type: text/css");
 if (isset($_GET['logged_on'])) {
     define("LOGON", true);
     echo "/* This is the default CSS, the user is not logged on */";
-    $cssfile="logon.css";
+    $cssfile="logon.css.php";
 } else {
     echo "/* This is the customized CSS, user is logged on */";
     $cssfile="css.php";
