@@ -24,6 +24,8 @@
 
 use conf\conf;
 
+use file\archive;
+
 use photo\collection;
 
 use template\template;
@@ -44,7 +46,7 @@ if ($_action=="getfile" || $_action=="download") {
         die("Invalid filename");
     }
 
-    $filenum=getvar("_filenum");
+    $filenum=(int) getvar("_filenum");
     if (!$filenum) {
         $filenum=1;
     }
@@ -95,7 +97,9 @@ $downloadCount = sizeof($photos);
 
 if ($_action=="getfile") {
     $maxsize=getvar("_maxsize");
-    if (!$maxsize) { $maxsize=25000000; }
+    if (!$maxsize) {
+        $maxsize=-1;
+    }
 
     if (!is_numeric($maxsize)) {
         die("Maximum size must be numeric");
@@ -105,7 +109,10 @@ if ($_action=="getfile") {
     if ($downloadCount) {
         echo translate("The zipfile is being created...") . "<br>";
         flush();
-        $number=create_zipfile($photos, $maxsize, $filename, $filenum, $user);
+        $zip = new archive(archive::ZIP, $filename, $filenum);
+        $zip->setMaxSize($maxsize);
+        $number=$zip->addPhotos($photos);
+
         $newoffset=$offset + $number;
         echo "<iframe style=\"border: none; width: 100%; height: 4em\" " .
             "src=download.php?_action=download&_filename=" . $filename .
@@ -130,11 +137,10 @@ if ($_action=="getfile") {
             </ul>
             <?php
         } else {
-            $link = breadcrumb::getLast()->getLink();
             echo sprintf(translate("All photos have been downloaded in %s zipfiles."), $filenum)
             ?>
             <ul class="actionlink">
-              <li><a href="<?php echo $link ?>">
+              <li><a href="<?php echo  breadcrumb::getLast()->getURL() ?>">
                 <?php echo translate("Go back")?>
               </a></li>
             </ul>
