@@ -72,7 +72,7 @@ if (empty($qs)) {
 
 
 $tplActionlinks=new block("actionlinks", array(
-    "actionlinks"   =>  array("return" => "photos.php?" .  $qs),
+    "actionlinks"   =>  array(translate("return") => "photos.php?" .  $qs),
 ));
 
 $photoCollection = collection::createFromRequest(request::create());
