@@ -31,10 +31,12 @@ use template\fieldset;
 use template\form;
 use template\template;
 
-$actionlinks=array(
-    "return"    => "places.php",
-    "new"       => "place.php?_action=new"
-);
+$actionlinks = array();
+$actionlinks[translate("return")] = "places.php";
+
+if ($_action != "new") {
+    $actionlinks[translate("new")] = "place.php?_action=new";
+}
 
 $tpl=new template("edit", array(
     "title"         => translate($_action . " " . "place"),
