@@ -62,6 +62,9 @@ case "import.php":
     $scripts[]="js/import.js";
     $scripts[]="js/formhelper.js";
     $scripts[]="js/rating.js";
+    if(conf::get("import.upload")) {
+        $scripts[]="js/upload.js";
+    }
     break;
 case "config.php":
     $scripts[]="js/conf.js";
@@ -99,10 +102,12 @@ $html_title=conf::get("interface.title");
 if (isset($title)) {
     $html_title.=" - " . $title;
 }
+
+
 ?>
 
-<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN">
-<html>
+<!DOCTYPE html>
+<html lang="<?= language::getCurrentISO() ?>">
 
 <?php
 $hdrParams=array(
