@@ -31,7 +31,8 @@ $title = translate("About");
 $tpl = new template("info", array(
     "infoArray" => report::getInfoArray(),
     "title"     => $title,
-    "mailaddr"  => template::getImage("mailaddr.png")
+    "mailaddr"  => template::getImage("mailaddr.png"),
+    "credits"   => zoph::getCredits()
 ));
 
 echo $tpl;
