@@ -20,71 +20,70 @@ var photoPeople=function() {
     var peopleInPhoto;
 
     function init() {
-        div = document.getElementById("editPeople");
-        photoId=document.querySelectorAll('[name="photo_id"]')[0].value;
+        var div = document.getElementById("editPeople");
+        let photoId=document.querySelectorAll('[name="photo_id"]')[0].value;
         if(div && photoId) {
             zJSON.getData("photoPeople", "photoId=" + photoId, photoPeople);
         }
     
     }
     function transform() {
-        rows = [];
-        photoId=document.querySelectorAll('[name="photo_id"]')[0].value;
-        div = document.getElementById("editPeople");
-        personrows = document.getElementsByClassName("personrows")[0];
-        pc = personrows.childNodes
-        for(var c in pc) {
-            if (pc[c].nodeName=="LI") {
-                rows.push(pc[c]);
+        let rows = [];
+        let personrows = document.getElementsByClassName("personrows")[0];
+        let pc = personrows.childNodes;
+        
+        let photoId=document.querySelectorAll('[name="photo_id"]')[0].value;
+
+        for(var c of pc) {
+            if (c.nodeName=="LI") {
+                rows.push(c);
             }
         }
-        
-        for(var r in rows) {
-            peoplerow = rows[r].firstElementChild.childNodes;
-            people = [];
+        let r=0;
+        for(var row of rows) {
+            let people = [];
+            r++;
+            let peoplerow = row.firstElementChild.childNodes;
 
-            add=document.createElement("div");
+            let add=document.createElement("div");
             add.className="add";
             add.setAttribute("onClick", "photoPeople.addPerson(" + photoId + ", " + r + ")");
-            rows[r].insertBefore(add, rows[r].firstElementChild);
+            row.insertBefore(add, row.firstElementChild);
             
-            for (var p in peoplerow) {
-                if (peoplerow[p].nodeName=="LI") {
-                    people.push(peoplerow[p]);
+            for (const person of peoplerow) {
+                if (person.nodeName=="LI") {
+                    people.push(person);
 
                 }
             }
 
-
-
-            for (var p in people) {
-
-                id=people[p].attributes["data-id"].nodeValue;
+            for (const p in people) {
+                var id=people[p].attributes["data-id"].nodeValue;
 
                 if (p != 0) {  
-                    left=document.createElement("div");
+                    let left=document.createElement("div");
                     left.className="left";
                     left.setAttribute("onClick", "photoPeople.movePerson(" + id+ " ,'left')");
                     people[p].insertBefore(left, people[p].firstElementChild);
                 }
                 
                 if( (parseInt(p) + 1) != people.length) {
-                    right=document.createElement("div");
+                    let right=document.createElement("div");
                     right.className="right";
                     right.setAttribute("onClick", "photoPeople.movePerson(" + id+ " ,'right')");
                     people[p].insertBefore(right, people[p].firstElementChild);
                 }
-                up=document.createElement("div");
+                let up=document.createElement("div");
                 up.className="up";
                 up.setAttribute("onClick", "photoPeople.movePerson(" + id+ " ,'up')");
                 people[p].insertBefore(up, people[p].firstElementChild);
                 
-                down=document.createElement("div");
+                let down=document.createElement("div");
                 down.className="down";
                 down.setAttribute("onClick", "photoPeople.movePerson(" + id+ " ,'down')");
                 people[p].insertBefore(down, people[p].firstElementChild);
                 
-                remove=document.createElement("div");
+                let remove=document.createElement("div");
                 remove.className="remove";
                 remove.setAttribute("onClick", "photoPeople.movePerson(" + id+ " ,'remove')");
                 people[p].insertBefore(remove, people[p].firstElementChild);
@@ -100,7 +99,7 @@ var photoPeople=function() {
     }
 
     function removePeople() {
-        div = document.getElementById("editPeople");
+        let div = document.getElementById("editPeople");
         //personrows = document.getElementsByClassName("personrows")[0];
         while (div.hasChildNodes()) {
             div.removeChild(div.childNodes[0]);
@@ -108,11 +107,11 @@ var photoPeople=function() {
     }
 
     function addPerson(photoId, row) {
-        div=document.createElement("div");
+        let div=document.createElement("div");
         div.id="addPeopleModal"
         div.className="modal";
         if(autocomppeople) {
-            div.innerHTML="<h1>" + zTranslate.get("Add person") + "<img src='" + icons["remove"] + "' onClick='photoPeople.closeModal()'></h1><fieldset name='person_id[0]' class='multiple'><input type=hidden id=person_id[0]><input type='text' class='autocomplete' id='_person_id[0]'></fieldset><input type=button onClick='photoPeople.handleAddPeople(" + photoId + "," + row + ")' value='" + zTranslate.get("add") + "'>";
+            div.innerHTML="<h1>" + zTranslate.get("Add person") + "<img src='" + icons["remove"] + "' onClick='photoPeople.closeModal()'></h1><fieldset name='person_id[0]' class='multiple'><input type=hidden id=person_id[0]><input type='text' class='autocomplete' id='_person_id[0]'></fieldset><input type=button onClick='photoPeople.handleAddPeople(" + photo_id + "," + row + ")' value='" + zTranslate.get("add") + "'>";
             document.body.appendChild(div);
             autocomplete.init();
         } else {
@@ -134,7 +133,7 @@ var photoPeople=function() {
                 zError.push(error);
                 id = 0;
             }
-            if(!id == 0) {
+            if(id != 0) {
                 zJSON.getData("photoPeople", "personId=" + id + "&photoId=" + photoId + "&row=" + row + "&action=add", photoPeople);
             }
         }
@@ -144,32 +143,31 @@ var photoPeople=function() {
     }
 
     function closeModal() {
-        modal = document.getElementById("addPeopleModal");
+        let modal = document.getElementById("addPeopleModal");
         modal.parentElement.removeChild(modal);
 
     }
     
     function addPeopleFromJSON(json) {
         photoPeople.peopleInPhoto = [];
-        div = document.getElementById("editPeople");
-        personrows = document.createElement("ul");
+        let div = document.getElementById("editPeople");
+        let personrows = document.createElement("ul");
         personrows.className="personrows";
         
-        parsed = JSON.parse(json);
-        people = parsed.people;
+        let parsed = JSON.parse(json);
+        let people = parsed.people;
         if (people.length == 0) {
             people.push("");
         }
-        for (row in people) {
-            li = document.createElement("li");    
-            ul = document.createElement("ul");    
+        for (let row in people) {
+            let li = document.createElement("li");    
+            let ul = document.createElement("ul");    
             ul.className="people";
-            for (pos in people[row]) {
-                person=people[row][pos];
-                personli = document.createElement("li");
+            for (let person of people[row]) {
+                let personli = document.createElement("li");
                 personli.setAttribute("data-id", person.id);
                 photoPeople.peopleInPhoto.push(person.id);
-                a = document.createElement("a");
+                let a = document.createElement("a");
                 a.href = person.url;
                 a.innerHTML=person.name;
                 personli.appendChild(a);
@@ -183,6 +181,7 @@ var photoPeople=function() {
     }        
 
     function movePerson(id, dir) {
+        let photoId=document.querySelectorAll('[name="photo_id"]')[0].value;
         zJSON.getData("photoPeople", "personId=" + id + "&photoId=" + photoId + "&action=" + dir, photoPeople);
     }
 
