@@ -59,7 +59,7 @@ var slideshow=function() {
         var people=[];
 
         var photo = document.getElementById("photo");
-        photonew=photo.cloneNode(true);
+        let photonew=photo.cloneNode(true);
         photonew.srcset = data.image + " 2x, " + data.image + " 1x";
         photonew.src = data.image;
         photo.parentNode.replaceChild(photonew, photo);
@@ -79,15 +79,15 @@ var slideshow=function() {
         array2ul(data.albums, "slide-albums");
         array2ul(data.categories, "slide-categories");
 
-        exifdl = document.getElementById("slide-exifdata");
+        let exifdl = document.getElementById("slide-exifdata");
         while(exifdl.childNodes.length > 0) {
             exifdl.childNodes[0].parentNode.removeChild(exifdl.childNodes[0]);
         }
-        for (exif in data.exifdata) {
-            contents = data.exifdata[exif];
+        for (let exif in data.exifdata) {
+            let contents = data.exifdata[exif];
             if(contents.trim()) {
-                dt=document.createElement("dt");
-                dd=document.createElement("dd");
+                let dt=document.createElement("dt");
+                let dd=document.createElement("dd");
                 dt.innerHTML=exif;
                 dd.innerHTML=contents;
                 exifdl.appendChild(dt);
@@ -99,27 +99,27 @@ var slideshow=function() {
         }
 
         // Remove and re-add annotate block to trigger animation
-        annotate=document.getElementById("annotate");
-        annotatenew=annotate.cloneNode(true);
+        let annotate=document.getElementById("annotate");
+        let annotatenew=annotate.cloneNode(true);
         annotate.parentNode.replaceChild(annotatenew, annotate);
         
     }
 
     function array2ul(json, id) {
         // Remove current
-        current = document.getElementById(id).childNodes;
+        let current = document.getElementById(id).childNodes;
         while(current.length > 0) {
             current[0].parentNode.removeChild(current[0]);
         }
-        for (element in json) {
+        for (let element in json) {
             json2li(json[element], id);
         }
     }
 
     function json2li(jsondata, id) {
-        li=document.createElement("li");
+        let li=document.createElement("li");
         li.innerHTML=jsondata;
-        element=document.getElementById(id);
+        let element=document.getElementById(id);
         element.appendChild(li);
     }
 
