@@ -55,7 +55,7 @@ function removeChildren(obj) {
 }
 
 function clr(obj_id) {
-    object=document.getElementById(obj_id);
+    let object=document.getElementById(obj_id);
     removeChildren(object);
 }
 
@@ -65,8 +65,8 @@ function deleteNode(obj) {
 }
 
 function createNode(nodetype, value) {
-    var node=document.createElement(nodetype);
-    nodetext=document.createTextNode(value);
+    let node=document.createElement(nodetype);
+    let nodetext=document.createTextNode(value);
     node.appendChild(nodetext);
     return node;
 }
@@ -101,19 +101,19 @@ function findPos(obj) {
 function adjustIframe(min, max, iframe) {
     // This function will adjust the height of an iframe
     // to it's contents, with a set maximum;
-    html=document.getElementsByTagName("html")[0];
-    height=html.clientHeight + 20;
+    let html=document.getElementsByTagName("html")[0];
+    let height=html.clientHeight + 20;
     if(height > max) {
         height = max;
     } else if (height < min) {
         height = min;
     }
-    objiframe=top.document.getElementById(iframe);
+    let objiframe=top.document.getElementById(iframe);
     objiframe.style.height=height + "px";
 }
 
 function getFileType(url) {
-    ext=url.substr(url.lastIndexOf('.') + 1).toLowerCase();
+    let ext=url.substr(url.lastIndexOf('.') + 1).toLowerCase();
     switch(ext) {
     case "jpg":
     case "gif":
@@ -131,10 +131,10 @@ function getFileType(url) {
 
 
 function increaseValueInBrackets(value) {
-    leftbracket=value.indexOf("[");
-    rightbracket=value.indexOf("]");
+    let leftbracket=value.indexOf("[");
+    let rightbracket=value.indexOf("]");
 
-    num=parseInt(value.substring(leftbracket + 1, rightbracket),10);
+    let num=parseInt(value.substring(leftbracket + 1, rightbracket),10);
     num++;
     return value.substring(0,leftbracket) + "[" + num + "]";
 }
