@@ -49,7 +49,8 @@ var XML=function() {
         };
 
     function getData(object, constraint) {
-        var http=new XMLHttpRequest();
+        let http=new XMLHttpRequest();
+        let xmlobj, newobj;
 
         if(object=='import_progress') {
             xmlobj='import_progress';
@@ -73,7 +74,7 @@ var XML=function() {
         }
 
         if (http) {
-            input=document.getElementById(object);
+            let input=document.getElementById(object);
             if(input && input.nodeName=="INPUT") {
                 input.style.backgroundImage="url('" + icons["pleasewait"] + "')";
             }
@@ -90,7 +91,7 @@ var XML=function() {
     }
 
     function httpResponse(http, object) {
-        input=document.getElementById(object);
+        let input=document.getElementById(object);
         if (http.readyState == 4) {
             if(http.status == 200) {
                 if(input && input.nodeName=="INPUT") {
@@ -114,27 +115,27 @@ var XML=function() {
 
     function submitForm(form, url) {
         if(form.tagName=="FORM") {
-            inputs=form.getElementsByTagName("input");
-            selects=form.getElementsByTagName("select");
-            textareas=form.getElementsByTagName("textarea");
+            let inputs=form.getElementsByTagName("input");
+            let selects=form.getElementsByTagName("select");
+            let textareas=form.getElementsByTagName("textarea");
             if(url.indexOf("?")) {
                 url += "&";
             } else {
                 url += "?";
             }
-            for(var i=0; i<inputs.length; i++) {
-                if(inputs[i].value) {
-                    url += escape(inputs[i].name) + "=" + escape(inputs[i].value) + "&";
+            for(let input of inputs) {
+                if(input.value) {
+                    url += escape(input.name) + "=" + escape(input.value) + "&";
                 }
             }
-            for(i=0; i<selects.length; i++) {
-                if(selects[i].value) {
-                    url += escape(selects[i].name) + "=" + escape(selects[i].value) + "&";
+            for(let select of selects) {
+                if(select.value) {
+                    url += escape(selects[i].name) + "=" + escape(select.value) + "&";
                 }
             }
-            for(i=0; i<textareas.length; i++) {
-                if(textareas[i].value) {
-                    url += escape(textareas[i].name) + "=" + escape(textareas[i].value) + "&";
+            for(let textarea of textareas) {
+                if(textarea.value) {
+                    url += escape(textarea.name) + "=" + escape(textarea.value) + "&";
                 }
             }
             var http=new XMLHttpRequest();
