@@ -40,26 +40,7 @@ $subject = getvar("subject");
 $message = getvar("message");
 $includeurl = getvar("includeurl");
 
-if (conf::get("feature.annotate")) {
-    $annotate = getvar("annotate");
-    $annotate_vars = getvar("annotate_vars");
-} else {
-    $annotate=0;
-}
-
-if ($annotate) {
-    $skipcrumb = true;
-    $photo=new annotatedPhoto($photo_id);
-    if (!empty($annotate_vars)) {
-        parse_str($annotate_vars, $vars);
-    } else {
-        $vars=$request_vars;
-        $annotate_vars=http_build_query($vars, "&amp;");
-    }
-    $photo->setVars($vars);
-} else {
-    $photo = new photo($photo_id);
-}
+$photo = new photo($photo_id);
 
 $found = $photo->lookup();
 
@@ -79,10 +60,7 @@ else {
 
             $size = getvar("_size");
 
-            if ($annotate) {
-                $filename=$photo->get("name");
-                $size = $vars["_size"];
-            } else if ($size == "full") {
+            if ($size == "full") {
                 $filename = $photo->get("name");
                 $dir = conf::get("path.images") . "/" . $photo->get("path") . "/";
             } else {
@@ -104,13 +82,7 @@ else {
                 }
                 $html .= "</center>\n";
 
-                if ($annotate) {
-                    list($headers,$image)=$photo->display($size);
-                    $mail->addHTMLImageFromString($image, $photo->get("name"),
-                        $headers["Content-type"]);
-                } else {
-                    $mail->addHTMLImageFromFile($dir . "/" . $filename, $file->getMime());
-                }
+                $mail->addHTMLImageFromFile($dir . "/" . $filename, $file->getMime());
                 $mail->setHTMLBody($html);
                 $mail->setTXTBody($message);
             } else {
@@ -121,13 +93,7 @@ else {
                     $message .= ": " . url::get() . "/photo.php?photo_id=" . $photo_id;
                 }
                 $mail->setTXTBody($message);
-                if ($annotate) {
-                    list($headers,$image)=$photo->display($size);
-                    $mail->addAttachmentFromString($image, $photo->get("name"),
-                        $headers["Content-type"]);
-                } else {
-                    $mail->addAttachmentFromFile($dir . "/" . $filename, $file->getMime());
-                }
+                $mail->addAttachmentFromFile($dir . "/" . $filename, $file->getMime());
             }
             $mail->setFrom("$from_name <$from_email>");
 
@@ -158,17 +124,6 @@ require_once "header.inc.php";
 ?>
 
       <h1>
-<?php
-if (conf::get("feature.annotate")) {
-    ?>
-      <ul class="actionlink">
-        <li><a href="define_annotated_photo.php?photo_id=<?php echo $photo->getId() ?>">
-          <?php echo translate("create annotated photo", 0) ?>
-        </a></li>
-      </ul>
-    <?php
-    }
-?>
 <?php echo translate("email photo") ?>
       </h1>
 <form action="<?php echo $_SERVER["PHP_SELF"] ?>" method="post">
@@ -195,7 +150,6 @@ if ($found && $_action == "compose") {
     ?>
     <input type="hidden" name="_action" value="mail">
     <input type="hidden" name="photo_id" value="<?php echo $photo_id ?>">
-    <input type="hidden" name="annotate" value="<?php echo $annotate ?>">
     <label for="html"><?php echo translate("send as html") ?></label>
     <?php echo template::createYesNoPulldown("html", "1") ?><br>
     <label for="toname"><?php echo translate("to (name)") ?></label>
@@ -208,35 +162,16 @@ if ($found && $_action == "compose") {
     <?php echo create_text_input("from_email", $from_email, 24, 64) ?><br>
     <label for="subject"><?php echo translate("subject") ?></label>
     <?php echo create_text_input("subject", $subject, 48, 64) ?><br>
-    <?php
-    if (!$annotate) {
-        ?>
-        <label for="size"><?php echo translate("send fullsize") ?></label>
-        <?php echo template::createPulldown("_size", "mid", array(
-            "full" => translate("Yes",0),
-            "mid" => translate("No",0))); ?>
-        <br>
-        <label for="includeurl"><?php echo translate("include URL") ?></label>
-        <?php echo template::createYesNoPulldown("includeurl", "1") ?><br>
-        <?php
-    }
-    ?>
+    <label for="size"><?php echo translate("send fullsize") ?></label>
+    <?php echo template::createPulldown("_size", "mid", array(
+        "full" => translate("Yes",0),
+        "mid" => translate("No",0))); ?>
+    <br>
+    <label for="includeurl"><?php echo translate("include URL") ?></label>
+    <?php echo template::createYesNoPulldown("includeurl", "1") ?><br>
     <label for="message"><?php echo translate("message:") ?></label><br>
     <textarea name="message" class="email" cols="70" rows="5"><?php echo $body ?></textarea>
-    <?php
-    if ($annotate) {
-        ?>
-        <input type="hidden" name="annotate_vars" value="<?php echo $annotate_vars ?>">
-        <img src="image.php?photo_id=<?php echo $photo_id
-           ?>&annotated=1&<?php echo $annotate_vars ?>"
-           alt="<?php echo $photo->get("title") ? $photo->get("title") : $photo->get("name") ?>">
-        <?php
-    } else {
-        ?>
-        <?php echo $photo->getImageTag(MID_PREFIX) ?>
-        <?php
-    }
-    ?>
+    <?php echo $photo->getImageTag(MID_PREFIX) ?>
     <input type="submit" name="_button" value="<?php echo translate("email", 0); ?>">
     <?php
 }
