@@ -65,6 +65,8 @@ if ($_action == "mail") {
 
     $body = $mail->get();
     $hdrs = $mail->headers($hdrs);
+
+    $headers = "";
     foreach ($hdrs as $header => $content) {
         $headers .= $header . ": " . e($content) . "\n";
     }
@@ -79,7 +81,7 @@ if ($_action == "mail") {
             }
         }
     } else {
-        $msg .= translate("Could not send mail.");
+        $msg = translate("Could not send mail.");
     }
 } else {
 
