@@ -29,6 +29,7 @@ $zophpage = new page($zophpage_id);
 
 $obj = &$zophpage;
 
+$redirect = "pages.php";
 require_once "actions.inc.php";
 
 if ($zophpage_id) {
@@ -37,12 +38,15 @@ if ($zophpage_id) {
     if (empty($title)) {
         $title=translate("Page");
     }
+    $returnURL = "page.php?page_id=" . $zophpage->getId();
 } else if ($_action == "new") {
     $title = translate("Create new page");
+    $returnURL = "pages.php";
 } else if ($_action != "insert") {
     // no id given and action is not new or insert
     redirect("zoph.php", "No page id given!");
 } else {
+    $returnURL = "page.php?page_id=" . $zophpage->getId();
     $title = $zophpage->get("title");
 }
 
@@ -61,8 +65,7 @@ if ($action == "confirm") {
                     echo $zophpage->getId() ?>">
                   <?php echo translate("delete") ?>
                 </a></li>
-                <li><a href="page.php?_action=edit&amp;page_id=<?php
-                    echo $zophpage->getId() ?>">
+                <li><a href="<?= $returnURL ?>">
                   <?php echo translate("cancel") ?>
                 </a></li>
             </ul>
@@ -108,6 +111,11 @@ if ($action == "confirm") {
     ?>
     <h1>
         <?php echo $title ?>
+        <ul class="actionlink">
+            <li><a href="<?= $returnURL ?>">
+              <?php echo translate("return") ?>
+            </a></li>
+        </ul>
     </h1>
     <div class="main">
         <br>
