@@ -54,13 +54,16 @@ if ($_action == "insert") {
     $action="display";
 }
 $obj = &$pageset;
+$redirect = "pagesets.php";
 
 require_once "actions.inc.php";
 
 if ($_action != "new") {
     $title = $pageset->get("title");
+    $returnURL = "page.php?page_id=" . $pageset->getId();
 } else {
     $title = translate("Create new pageset");
+    $returnURL = "pagesets.php";
 }
 require_once "header.inc.php";
 ?>
@@ -73,7 +76,7 @@ if ($action == "confirm") {
              <li><a href="pageset.php?_action=confirm&amp;pageset_id=<?php
                 echo $pageset->getId() ?>"><?php echo translate("delete") ?>
              </a></li>
-             <li><a href="pageset.php?_action=edit&amp;pageset_id=<?php
+             <li><a href="pageset.php?pageset_id=<?php
                 echo $pageset->getId() ?>"><?php echo translate("cancel") ?>
              </a></li>
            </ul>
@@ -123,6 +126,18 @@ if ($action == "confirm") {
 } else {
     ?>
     <h1>
+        <ul class="actionlink">
+            <li>
+                <a href="<?= $returnURL ?>">
+                    <?php echo translate("return") ?>
+                </a>
+            </li>
+            <li>
+                <a href="pageset.php?_action=delete&amp;pageset_id=<?= $pageset->getId() ?>">
+                    <?php echo translate("delete") ?>
+                </a>
+            </li>
+        </ul>
         <?php echo $title ?>
     </h1>
     <div class="main">
