@@ -22,6 +22,9 @@
  * @author Jeroen Roos
  */
 
+use template\block;
+use template\template;
+
 require_once "include.inc.php";
 $_view=getvar("_view");
 $_showhidden=(bool) getvar("_showhidden");
@@ -64,7 +67,7 @@ if (getvar("circle_id")) {
             "coverphoto"    => "circle.php?_action=update&amp;circle_id=" . $circle->getId() . "&amp;coverphoto=",
             "return"        => "_return=circle.php&amp;_qs=circle_id=" . $circle->getId()
         ));
-    } catch (PhotoNoSelectionException $e) {
+    } catch (photoNoSelectionException $e) {
         $selection=null;
     }
 
@@ -83,7 +86,13 @@ if (getvar("circle_id")) {
 require_once "header.inc.php";
 
 $tpl=new template("organizer", array(
+    "pageTop"           => false,
+    "pageBottom"        => false,
+    "showMain"          => true,
     "title"     => strtolower($title),
+    "ancLinks"  => null,
+    "coverphoto"    => null,
+    "description"   => null,
     "selection" => $selection,
     "view"      => $_view,
     "view_name" => "People view",
