@@ -38,7 +38,7 @@ $controller = new searchController(request::create());
 
 $search=$controller->getObject();
 if ($controller->getView() == "insert") {
-    $title = translate("New Search");
+    $title = translate("Save search");
 } else if ($search instanceof search) {
     $title = $search->get("description");
     if (empty($title)) {
@@ -74,7 +74,6 @@ if ($controller->getView() == "display") {
 } else {
     $actionlinks=array(
         translate("return") => "search.php",
-        translate("new")    => "search.php?_action=new"
     );
 
     $tpl=new template("edit", array(
