@@ -23,19 +23,19 @@ if (!ZOPH) { die("Illegal call"); }
 require_once "header.inc.php";
 ?>
     <h1>
-        <?php echo $tpl_title; ?>
+        <?= $tpl_title; ?>
     </h1>
     <div class="main">
         <ul class="admin">
             <?php foreach ($tpl_adminpages as $adminpage): ?>
             <li>
-                <a href="<?php echo $adminpage->url ?>">
-                    <img src="<?php echo $adminpage->icon; ?>">
+                <a href="<?= $adminpage->url ?>">
+                    <img src="<?= $adminpage->icon; ?>" alt="<?= translate($adminpage->name) ?>">
                     <br>
-                    <?php echo translate($adminpage->name); ?>
+                    <?= translate($adminpage->name); ?>
                 </a>
             </li>
             <?php endforeach; ?>
         </ul>
     </div>
-    <?php require_once "footer.inc.php"; ?>
+<?php require_once "footer.inc.php"; ?>
