@@ -26,6 +26,8 @@ if (!ZOPH) { die("Illegal call"); }
     <input type="hidden" name="_action" value="rate">
     <input type="hidden" name="photo_id" value="<?= $tpl_photoId ?>">
     <?= $tpl_ratingPulldown ?>
-    <input type="submit" name="_button" value="<?= translate("rate", 0) ?>">
+    <input type="submit" id="ratingsubmit" name="_button" value="<?= translate("rate", 0) ?>">
 </form>
-
+<script type="text/javascript">
+    zRating.ratingButton("ratingsubmit", "rating");
+</script>
