@@ -27,7 +27,7 @@ if (!ZOPH) {
 ?>
 
 <div class="message <?= $tpl_class ?>">
-    <img class='icon' src='<?php echo template::getImage("icons/" . $tpl_class . ".png") ?>'>
+    <img alt="<?= $tpl_class ?>" class='icon' src='<?php echo template::getImage("icons/" . $tpl_class . ".png") ?>'>
     <?php if (isset($tpl_title)): ?>
         <h1><?= $tpl_title ?></h1>
     <?php endif ?>
