@@ -22,8 +22,10 @@
 if (!ZOPH) { die("Illegal call"); }
 ?>
 <table class="reports">
+    <caption><?php echo $tpl_title ?></caption>
     <tr>
-        <th colspan="3"><h3><?php echo $tpl_title ?></h3></th>
+        <th scope="col"><?= translate("title") ?></th>
+        <th scope="col"><?= translate("count") ?></th>
     </tr>
     <?php foreach ($tpl_lines as $line): ?>
     <tr>
