@@ -24,7 +24,8 @@ if (!ZOPH) {
 }
 ?>
     <form class="search" enctype="multipart/form-data" action="search.php" method="POST">
+        <input type="hidden" name="_action" value="search">
         <?= $this->displayBlocks(); ?>
-        <input type="submit" name="_action" value="<?= $tpl_submit ?>">
+        <input type="submit" value="<?= translate("search") ?>">
     </form>
 
