@@ -30,4 +30,7 @@ if (!ZOPH) {
 <div class="main">
     <?= sprintf(translate("Confirm deletion of '%s'"), $tpl_obj->getName()) ?>
     <?= $this->getActionlinks($tpl_mainActionlinks) ?>
+    <?php if (isset($tpl_image)): ?>
+        <div><?= $tpl_image ?></div>
+    <?php endif ?>
 </div>
