@@ -795,6 +795,14 @@ table.reports {
     padding: 10px 5px 20px 5px;
 }
 
+table#users th,
+table.reports th {
+    text-align: left;
+    color: <?= colorScheme::getColor("title_font_color") ?>;
+    opacity: 30%;
+    font-weight: normal;
+}
+
 table.pages, table.pagesets {
     width: 100%;
 }
@@ -1010,6 +1018,13 @@ div.cs_example {
 table.colorschemes {
     width: 100%;
 }
+
+caption {
+    font-size: 1.4rem;
+    font-weight: bold;
+    margin: 0.5em;
+}
+
 /* Tables for the permissions */
 
 table.permissions   {
@@ -1019,7 +1034,8 @@ table.permissions   {
     margin-right: auto;
     border-collapse: collapse;
     font-size: medium;
-    }
+    margin: 2em 0;
+}
 
 table.permissions td, table.permissions th  {
     background: <?= colorScheme::getColor("table_bg_color") ?>;
@@ -2167,12 +2183,12 @@ table.credits td {
 
 table#zophinfo {
     width: 60%;
-    margin-left: auto;
-    margin-right: auto;
+    margin: 2em auto;
 }
 
 table#zophinfo th {
-    width: 80%;
+    width: 60%;
+    text-align: left;
 }
 
 table#zophinfo td {
@@ -2238,22 +2254,6 @@ div.page div.background {
 }
 
 /* Styles for the import page */
-html.iframe_upload {
-    width: 100%;
-    clear: both;
-}
-
-html.iframe_upload body {
-    background: transparent;
-    width: 100%;
-    clear: both;
-}
-
-html.iframe_upload input {
-    margin: 5px;
-}
-
-
 div.import_thumbs,
 div.import_uploads,
 div.import,
@@ -2261,6 +2261,7 @@ div.import_details {
     float:      left;
     border-radius: 5px;
     background: <?= colorScheme::getColor("title_bg_color") ?>;
+    box-shadow: 5px 5px 10px rgba(0,0,0,0.2);
     margin: 10px;
     width: 95%;
 }
@@ -2271,7 +2272,7 @@ div.import_thumbs {
 }
 
 div.import_thumbs div.thumbnail {
-    min-height: <?= THUMB_SIZE + 30 ?>px;
+    min-height: <?= THUMB_SIZE + 40 ?>px;
     height: auto;
     overflow: hidden;
 }
@@ -2299,20 +2300,77 @@ div.import_thumbs ul.categories li.unknown {
     background: #ffbbbb;
 }
 
-div.import textarea {
+div.import textarea { /// CHECK
     width: 60%;
 }
 
-iframe.upload {
-    width: 100%;
-    margin-bottom: 3px;
-    height: 100px;
+div.hover,
+div.drop {
+    display: none;
+    font-weight: bold;
+    text-align: center;
+    padding: 2em;
+    margin: 2em 2em;
+    color: <?= colorScheme::getColor("page_bg_color") ?>;
+    border: 2px dashed <?= colorScheme::getColor("page_bg_color") ?>;
+    border-radius: 10px;
+    cursor: default;
 }
 
-div.uploadprogress {
-    display: none;
-    float: right;
-    width: 350px;
+div.hover {
+    background: rgba(0,0,0,0.1);
+    border: 2px solid <?= colorScheme::getColor("page_bg_color") ?>;
+    box-shadow: inset 3px 3px 6px rgba(0,0,0,0.2), 0px 0px 15px 7px rgb(255,255,255);
+}
+
+div.upload {
+    height: 4em;
+    margin: 1em;
+    background: rgba(255,255,255,0.1);
+    border: 1px dashed rgba(0,0,0,0.5);
+    padding: 0.5em;
+    border-radius: 5px;
+    box-shadow: 3px 3px 5px rgba(0,0,0, 0.5);
+    
+}
+
+div#uploadResults div.uploadError {
+    height: 5em;
+}
+div#uploadResults div.uploadError span {
+    font-weight: bold;
+}
+
+div#uploadResults {
+    padding: 2em;
+}
+
+div#uploadResults div {
+    transition: opacity 4s ease-in;
+}
+
+div#uploadResults div.completed {
+    opacity: 0%;
+}
+
+div#uploadResults div.uploadError progress::-moz-progress-bar {
+    background-color: red;
+}
+
+div#uploadResults progress {
+    margin: 0.5em;
+    width: calc(100% - 1em);
+    height: 1em;
+    border-radius: 4px;
+}
+
+div#uploadResults progress::-moz-progress-bar {
+    border-radius: 4px;
+}
+
+div#uploadResults div.completed progress::-moz-progress-bar {
+    background-color: green;
+    border-radius: 4px;
 }
 
 div.import_details,
@@ -2328,8 +2386,7 @@ div.import_thumbs h2,
 div.import_uploads h2,
 div.import h2,
 div.import_details h2 {
-    border-radius-top-left: 5px;
-    border-radius-top-right: 5px;
+    border-radius: 5px 5px 0 0;
     background: <?= colorScheme::getColor("breadcrumb_bg_color") ?>;
     color: <?= colorScheme::getColor("title_font_color") ?>;
     border-bottom: 1px solid <?= colorScheme::getColor("table_border_color") ?>;
@@ -2339,35 +2396,8 @@ div.import_details h2 {
     font-size: large;
     font-weight: bold;
     display: block;
-    padding: 3px 0;
-}
-
-
-.upload {
-    width:      100%;
-    height:     80px;
-}
-
-.progressbar {
-    margin: auto;
-    height: 20px;
-    background: white;
-    border: 1px solid black;
-    border-radius: 5px;
-    overflow: hidden;
-    clear: both;
-}
-
-.progressfill {
-    height: 16px;
-    margin: 2px;
-    max-width: 99%;
-    border-radius: 4px;
-    text-align: center;
-    background: <?= colorScheme::getColor("page_bg_color") ?>;
-    color: white;
-    font-weight: bold;
-    overflow: hidden;
+    padding: 6px 0;
+    margin: 0 0 5px 0;
 }
 
 span.filename {
@@ -2376,24 +2406,6 @@ span.filename {
     font-size: 70%;
 }
 
-.fn_upload {
-    margin: 2px;
-    display: block;
-    float: left;
-    font-weight: bold;
-    clear: both;
-    font-size: 80%;
-    margin-bottom: 0;
-}
-
-.sz_upload {
-    margin: 2px;
-    clear: right;
-    display: block;
-    font-size: 60%;
-    float: right;
-}
-
 form.import {
     padding: 1.5em 0em 2em 0em;
 }
