@@ -23,8 +23,8 @@ if (!ZOPH) {
 }
 ?>
 
-<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN">
-<html>
+<!DOCTYPE html>
+<html lang="<?= $tpl_lang ?>">
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
 <title><?= $tpl_title ?></title>
