@@ -24,12 +24,28 @@ if (!ZOPH) {
 }
 ?>
 
-<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01//EN\">
-<html class="<?php echo $tpl_html_class ?>">
+<!DOCTYPE html>
+<html lang="<?= $tpl_lang ?>" class="<?php echo $tpl_html_class ?>">
     <head>
-        <?php echo $this->getHead(); ?>
+        <?php foreach ($tpl_js as $js): ?>
+            <script type='text/javascript' src="<?= $js ?>"></script>
+        <?php endforeach ?>
+        <?php foreach ($tpl_css as $css): ?>
+            <link type='text/css' rel="stylesheet" href="<?= $css ?>">
+        <?php endforeach ?>
+        <?php if (!empty($tpl_style)):  ?>
+            <style>
+                <?= $tpl_style ?>
+            </style>
+        <?php endif ?>
+        <?php if (!empty($tpl_script)):  ?>
+            <script type='text/javascript'>
+                <?= $tpl_script ?>
+            </script>
+        <?php endif ?>
+        <title><?= $tpl_title ?></title>
     </head>
     <body>
-        <?php echo $tpl_body; ?>
+        <?= $tpl_body; ?>
     </body>
 </html>
