@@ -36,18 +36,14 @@ if (!ZOPH) { die("Illegal call"); }
     <div class="main">
         <noscript>
           <div class="message warning">
-            <img class="icon" src="<?= template::getImage("icons/warning.png") ?>">
+            <img alt="warning" class="icon" src="<?= template::getImage("icons/warning.png") ?>">
             <?= translate("This page needs Javascript switched on and will not " .
                 "function without it."); ?><br>
           </div>
        </noscript>
         <div class="import_uploads">
             <h2><?php echo translate("Upload photo",0);?></h2>
-            <iframe class="upload" id="upload_<?php echo $tpl_num; ?>"
-                src="import.php?_action=browse&upload_id=<?php
-                echo $tpl_upload_id ?>&num=<?php echo $tpl_num ?>"
-                allowtransparency=1 frameborder=0>
-            </iframe>
+            <?= $tpl_upload ?>
         </div>
         <div id="import_details" class="import_details">
             <h2>
