@@ -39,9 +39,10 @@ require_once "header.inc.php";
     <?php if ($user->isAdmin()): ?>
         <br>
         <table id="zophinfo">
+            <caption><?= translate("About") ?></caption>
             <?php foreach ($tpl_infoArray as $field => $value): ?>
                 <tr>
-                    <th><?= $field ?></th>
+                    <th scope="row"><?= $field ?></th>
                     <td><?= $value ?></td>
                 </tr>
             <?php endforeach ?>
@@ -55,9 +56,10 @@ require_once "header.inc.php";
             "with thanks to the following for their contributions:", 0) ?>
     </p>
     <table class="credits">
+        <caption><?= translate("Credits") ?></caption>
         <?php foreach ($tpl_credits as $name => $credit): ?>
             <tr>
-                <th><?= $name ?></th>
+                <th scope="row"><?= $name ?></th>
                 <td><?= $credit ?></td>
             </tr>
         <?php endforeach ?>
