@@ -53,7 +53,7 @@ if (!$user->isAdmin()) {
 if ($_action=="" || $_action=="display") {
     $title = translate("Tracks");
     $tracks=track::getAll();
-    if (count($tracks>0)) {
+    if (count($tracks)>0) {
         $content=new block("tracks_table", array(
             "tracks" => $tracks
         ));
