@@ -62,16 +62,16 @@ require_once "header.inc.php";
 
 if ($action == "display") {
     $actionlinks=array(
-        "edit"      => "user.php?_action=edit&amp;user_id=" . $this_user->getId(),
-        "delete"    => "user.php?_action=delete&amp;user_id=" . $this_user->getId(),
-        "new"       => "user.php?_action=new"
+        translate("edit")      => "user.php?_action=edit&amp;user_id=" . $this_user->getId(),
+        translate("delete")    => "user.php?_action=delete&amp;user_id=" . $this_user->getId(),
+        translate("new")       => "user.php?_action=new"
     );
 
     $notifyForm=new form("form", array(
         "formAction"        => "notify.php",
         "onsubmit"          => null,
         "action"            => "notifyuser",
-        "submit"            => translate("notify user")
+        "submit"            => translate("Notify User")
     ));
 
     $notifyForm->addInputHidden("user_id", $this_user->getId());
@@ -108,13 +108,12 @@ if ($action == "display") {
         "obj"               => $this_user
     ));
 } else {
-    $actionlinks=array(
-        translate("return")      => "users.php",
-        translate("new")       => "user.php?_action=new"
-    );
+    $actionlinks=array();
+    $actionlinks[translate("return")] = "users.php";
 
     if ($_action != "new") {
-        $actionlinks[translate("change password")]="password.php?userid=" . $this_user->getId();
+        $actionlinks[translate("new")] = "user.php?_action=new";
+        $actionlinks[translate("change password")] = "password.php?userid=" . $this_user->getId();
     }
 
     $tpl=new template("edit", array(
