@@ -39,6 +39,12 @@ require_once "header.inc.php";
     </h1>
     <div class="main">
       <table id="users">
+        <caption><?= translate("users") ?></caption>
+        <tr>
+            <th scope="col"><?= translate("username") ?></th>
+            <th scope="col"><?= translate("name") ?></th>
+            <th scope="col"><?= translate("last login") ?></th>
+        </tr>
 <?php
 $users = user::getAll();
 
