@@ -139,7 +139,7 @@ $warnings = conf::getWarnings();
 if ($warnings) {
     $warning=new block("message", array(
         "class" => "warning",
-        "text"  => "<h1>" . translate("Configuration Warnings:") . "</h1>" . implode($warnings, "<br>")
+        "text"  => "<h1>" . translate("Configuration Warnings:") . "</h1>" . implode("<br>", $warnings)
     ));
     echo $warning . "<br>";
 }
