@@ -1,6 +1,6 @@
 #
-# Zoph 0.3.2 -> 0.3.3 update
-# 18 Nov 2002
+# Zoph 0.2.1 -> 0.3 update
+# 20 Sep 2002
 #
 # This file is part of Zoph.
 #
@@ -16,8 +16,29 @@
 # You should have received a copy of the GNU General Public License
 # along with Zoph; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+#
+#
+# increase size of name and path photo fields
+#
+alter table photos modify name varchar(128);
+alter table photos modify path varchar(255);
 
 #
-# create a pref for displaying descriptions under thumbnails
+# create timestamp field
 #
-alter table prefs add desc_thumbnails char(1) not null default '0';
+alter table photos add timestamp timestamp(14);
+
+#
+# create a language pref field
+#
+alter table prefs add language char(2);
+
+#
+# create a field for the number of days used by the view recent links
+#
+alter table prefs add recent_photo_days smallint not null default 7;
+
+#
+# create a import permission field
+#
+alter table users add import char(1) not null default '0';
